Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2941)

Unified Diff: android_webview/browser/aw_browser_context.h

Issue 1474483004: WebView Metrics client implementation (Chromium part) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « android_webview/android_webview.gyp ('k') | android_webview/browser/aw_browser_context.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: android_webview/browser/aw_browser_context.h
diff --git a/android_webview/browser/aw_browser_context.h b/android_webview/browser/aw_browser_context.h
index 47ccb808db0a2ecae14a6a6e03d51c797b75e6d3..1702617a2e515a904806454d919a8d116c972107 100644
--- a/android_webview/browser/aw_browser_context.h
+++ b/android_webview/browser/aw_browser_context.h
@@ -9,6 +9,7 @@
#include "android_webview/browser/aw_download_manager_delegate.h"
#include "android_webview/browser/aw_message_port_service.h"
+#include "android_webview/browser/aw_metrics_service_client.h"
#include "android_webview/browser/aw_ssl_host_state_delegate.h"
#include "base/compiler_specific.h"
#include "base/files/file_path.h"
@@ -84,8 +85,9 @@ class AwBrowserContext : public content::BrowserContext,
static void SetDataReductionProxyEnabled(bool enabled);
static void SetLegacyCacheRemovalDelayForTest(int delay_ms);
// Maps to BrowserMainParts::PreMainMessageLoopRun.
void PreMainMessageLoopRun();
+ void PostMainMessageLoopRun();
// These methods map to Add methods in visitedlink::VisitedLinkMaster.
void AddVisitedURLs(const std::vector<GURL>& urls);
@@ -100,17 +102,12 @@ class AwBrowserContext : public content::BrowserContext,
content::URLRequestInterceptorScopedVector request_interceptors);
AwQuotaManagerBridge* GetQuotaManagerBridge();
-
AwFormDatabaseService* GetFormDatabaseService();
-
data_reduction_proxy::DataReductionProxySettings*
GetDataReductionProxySettings();
-
data_reduction_proxy::DataReductionProxyIOData*
GetDataReductionProxyIOData();
-
AwURLRequestContextGetter* GetAwURLRequestContext();
-
AwMessagePortService* GetMessagePortService();
policy::URLBlacklistManager* GetURLBlacklistManager();
« no previous file with comments | « android_webview/android_webview.gyp ('k') | android_webview/browser/aw_browser_context.cc » ('j') | no next file with comments »
@@ -84,8 +85,9 @@ class AwBrowserContext : public content::BrowserContext,
static void SetDataReductionProxyEnabled(bool enabled);
static void SetLegacyCacheRemovalDelayForTest(int delay_ms);
- // Maps to BrowserMainParts::PreMainMessageLoopRun.
+ // These map to BrowserMainParts::Pre/PostMainMessageLoopRun.
void PreMainMessageLoopRun();

Powered by Google App Engine
This is Rietveld 408576698